NONE top-level constant
int
const NONE
This numeric value represents N or n access mode flag.
Implementation
const int NONE = 0x00;
This numeric value represents N or n access mode flag.
const int NONE = 0x00;