Tinode constructor
Tinode(
- String appName,
- ConnectionOptions options,
- bool loggerEnabled, {
- bool reset = false,
Creates an instance of Tinode interface to interact with tinode server using websocket
appName name of the client
options connection configuration and api key
loggerEnabled pass true if you want to turn the logger on
Implementation
Tinode(String appName, ConnectionOptions options, bool loggerEnabled,
{bool reset = false}) {
_registerDependencies(options, loggerEnabled, reset: reset);
_resolveDependencies();
_configService.appName = appName;
_doSubscriptions();
}